@@ -22,6 +22,12 @@ Implementation Notes
 
 """
 
+try:
+    from typing import Union, Iterable
+    from fontio import Glyph
+except ImportError:
+    pass
+
 import gc
 
 __version__ = "0.0.0-auto.0"
@@ -31,13 +37,13 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Bitmap_Font.git"
 class GlyphCache:
     """Caches glyphs loaded by a subclass."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         self._glyphs = {}
 
-    def load_glyphs(self, code_points):
+    def load_glyphs(self, code_points: Union[int, str, Iterable[int]]) -> None:
         """Loads displayio.Glyph objects into the GlyphCache from the font."""
 
-    def get_glyph(self, code_point):
+    def get_glyph(self, code_point: int) -> Glyph:
         """Returns a displayio.Glyph for the given code point or None is unsupported."""
         if code_point in self._glyphs:
             return self._glyphs[code_point]
